Lua_DressUpModelPanel = class("Lua_DressUpModelPanel", Lua_DressUpBasePanel);
function Lua_DressUpModelPanel:ctor(p)
	self:superCall("ctor", p, "DressUpModelPanel_skin");
end

function Lua_DressUpModelPanel:buildShowItem()
	self:superCall("buildShowItem");
	self.selectedIdx = 1;

	self.btnInfo = Array();
	self.btnInfo:add({ textStr = LanUtil.getValue(301020) });
	self.btnInfo:add({ textStr = LanUtil.getValue(301021) });

    self.buttonList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
    self.buttonList:setSiblingIndex(0);
    self.buttonList:setLocation(-186, -17, 0);
    self.buttonList:setButtonStyle("role_atlas", "ui_grxx_button_001_n", "ui_grxx_button_001_p", 0, 0, 1, 1, 1);
    self.buttonList:setButtonText(0, 0, "AFB0B3", "A5703E", 28, 28, Lua_MyUISettings.huakangFontName, UnityEngine.FontStyle.Normal);
    self.buttonList:setButtonItem(129, 46);
    self.buttonList:setClickCallBack(self, self.onButtonClick);
    self.buttonList:setData(self.btnInfo);

	self.itemList = Lua_DragList.new(self.content, 630, 263, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -168, 0);
	self.itemList:setListCell(Lua_DressUpModelItem, 126, 126, 5);

	self.btnFunc:addClickFuntion(self, self.onBtnFuncClick);
end

function Lua_DressUpModelPanel:dispose()
	if self.buttonList ~= nil then
		self.buttonList:dispose();
		self.buttonList = nil;
	end
	if self.btnInfo ~= nil then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	self:superCall("dispose");
end

function Lua_DressUpModelPanel:updateShowInfo()
	self.buttonList:setSelected(self.selectedIdx);
end

function Lua_DressUpModelPanel:onButtonClick(index)
	self.selectedIdx = index;

	self.attr_bg_1:setEnable(true);
	self.attr_bg_2:setEnable(true);
	self.attrText.text = nil;
	self.prompt_1.text = nil;
	self.prompt_2.text = nil;

	local arr = DataCenter.roleUtil:getDressUpArr(self.mainType);
	local len = arr:getSize();
	local data = Array();
	for i = 1, len do
		if index == 1 then
			if arr[i].sub_type ~= 3 then
				data:add(arr[i]);
			end
		else
			if arr[i].sub_type == 3 then
				data:add(arr[i]);
			end
		end
	end

	len = data:getSize();
	if len > 0 then
		local idx;
		for i = 1, len do
			if self.data == nil then
				if arr[i].is_wear == 1 then
					idx = i;
					break;
				end
			else
				if arr[i].id == self.data.id then
					idx = i;
					break;
				end
			end
		end
		idx = idx or 1;

		self.itemList:setEnable(true);
		self.itemList:setArrayData(data);
		self.itemList:moveToIndex(idx, true);
		self.itemList:setSelectClick(idx);
		self:showNone(false)
	else
		self.itemList:setEnable(false);
		self:showNone(true)
		self:showModel(nil)
	end
end

function Lua_DressUpModelPanel:onDressUpSelected(data)
	if not self.isActive or data == nil or data.main_type ~= self.mainType then
		return
	end
	self.data = data;

	if strIsNullOrEmpty(data.attrStr) then
		self.attr_bg_2:setEnable(false);
		self.attrText.text = nil;
		self.prompt_1:setLangValue(301017);
	else
		self.attr_bg_2:setEnable(true);
		self.attrText.text = data.attrStr;
		self.prompt_1.text = nil;
	end

	if data.is_active == 1 then
		self.prompt_2:setLangValue(301018);
		self.btnFunc:setLangValue(301008);
	else
		if data.active_hero_id ~= nil then
			local config = Lua_HeroConfigData.getConfig(data.active_hero_id);
			if config ~= nil then
				self.prompt_2.text = LanUtil.formateStr(301019, config.name);
			end
		elseif data.active_item ~= nil then
			local tvo = Lua_ToolVo.createToolVo(data.active_item[1]);
			self.prompt_2.text = LanUtil.formateStr(301019, tvo.name);
		else
			self.prompt_2.text = nil;
		end
		self.btnFunc:setLangValue(301011);
	end

	self:showModel(data)
end

function Lua_DressUpModelPanel:showNone(value)
	if value then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createImage(self.content, "/images/common/xui_common_widget_029.png", 0, -168, 0, 0)

			self.noneText = UICreate.createLabel(self.content, nil, 120, -130, 100, 40, 26)
			self.noneText.pivotValue = 4
			self.noneText.fontName = Lua_MyUISettings.huakangFontName
			self.noneText.alignmentValue = 4
			self.noneText.horizontalOverflowValue = 1
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("686868")
			self.noneText:setLangValue(301023)
		end
		self.noneIcon:setEnable(true)
		self.noneText:setEnable(true)
	else
		if self.noneIcon then
			self.noneIcon:setEnable(false)
			self.noneText:setEnable(false)
		end
	end
end

function Lua_DressUpModelPanel:showModel(data)
	if data == nil then
		if self.modelEffImg then
			self.modelEffImg:setEnable(false)
		end
	else
		if self.modelEffImg == nil then
			self.modelEffImg = UICreate.createModelEffImg(self.content, data.modelUrl, data.modelSrc, -145, 305, 0, 0)
			self.modelEffImg:setCamField(2, 1, 100, true)
			self.modelEffImg:setCamPos(0, 2, -10)
			self.modelEffImg:setScale(0.8, 0.8, 1)
			self.modelEffImg:setModelEffDir(180)
			self.modelEffImg:setAction(0)
			self.modelEffImg.canRot = true
		else
			self.modelEffImg:setEnable(true)
			self.modelEffImg:setUrl(data.modelUrl, data.modelSrc)
		end
	end
end




















Lua_DressUpModelItem = class("Lua_DressUpModelItem", Lua_ListCell);
function Lua_DressUpModelItem:ctor(p)
	self:superCall("ctor", p, "DressUpAvatarItem_skin");
end

function Lua_DressUpModelItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_DressUpModelItem:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_DressUpModelItem:setData(data)
	self.data = data;

	self.icon:setAltas(self.data.atlas, self.data.sprite);
	self.icon:resetSize();
	self.icon:setGray(self.data.is_active ~= 1);
	
	if self.data.is_wear == 1 then
		self.signIcon:setEnable(true);
		self.signIcon:setAltas("role_atlas", "ui_grxx_label_02");
	elseif self.data.canActivate == 1 then
		self.signIcon:setEnable(true);
		self.signIcon:setAltas("role_atlas", "ui_grxx_label_01");
	else
		self.signIcon:setEnable(false);
	end
	self.signIcon:resetSize();
end

function Lua_DressUpModelItem:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);
	self.selectIcon:setEnable(bSelect);
end

function Lua_DressUpModelItem:onPressClick()
	if self.data == nil then
		return false;
	end
	Lua_MsgUtil.callFunc("SELECT_DRESSUP", self.data);
	return true;
end