Lua_DressUpTitlePanel = class("Lua_DressUpTitlePanel", Lua_DressUpBasePanel);
function Lua_DressUpTitlePanel:ctor(p)
	self:superCall("ctor", p, "DressUpTitlePanel_skin");
end

function Lua_DressUpTitlePanel:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_PersonalAvatarItem.new(self.content);
	self.avatarItem:setLocation(-158, 210, 0);

	local avatarId = DataCenter.roleData:getTempDressUp(Lua_DressUpDefine.MAINTYPE_HEAD);
	local frameId = DataCenter.roleData:getTempDressUp(Lua_DressUpDefine.MAINTYPE_FRAME);
	local titleId = DataCenter.roleData:getTempDressUp(Lua_DressUpDefine.MAINTYPE_TITLE);
	self.avatarItem:setAvatar(avatarId);
	self.avatarItem:setRoleFrame(frameId);
	self.avatarItem:setRoleTitle(titleId);

	self.itemList = Lua_DragList.new(self.content, 630, 378, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -100, 0);
	self.itemList:setListCell(Lua_DressUpTitleItem, 630, 114, 1);

	self.btnFunc:addClickFuntion(self, self.onBtnFuncClick);
	self.btnAddition:addClickFuntion(self, self.onBtnAdditionClick);

	self:onDressUpSelected(nil);
end

function Lua_DressUpTitlePanel:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	DataCenter.roleData.selectDressUpId = nil;
	self:superCall("dispose");
end

function Lua_DressUpTitlePanel:updateShowInfo()
	self.checkIsSame = true;

	local arr = DataCenter.roleUtil:getDressUpArr(self.mainType);
	self.itemList:setArrayData(arr);

	local index = 0;
	for i = 1, arr:getSize() do
		if arr[i].id == DataCenter.roleData:getTempDressUp(Lua_DressUpDefine.MAINTYPE_TITLE) then
			self.checkIsSame = false;
			index = i;
			break;
		end
	end
	if index > 0 then
		self.itemList:moveToIndex(index, true);
		self.itemList:setSelectClick(index);
	end
end

function Lua_DressUpTitlePanel:onDressUpSelected(data)
	if not self.isActive or data == nil or data.main_type ~= self.mainType then
		return
	end

	if data == nil or (self.checkIsSame == true and self.data == data) then
		self.data = nil;
		DataCenter.roleData.selectDressUpId = nil;
		self.btnFunc:setBtnEnable(false);
		self.avatarItem:setRoleTitle(nil);
		self.name.text = nil;
		self.clockIcon:setEnable(false);
		self.time.text = nil;
		self.prompt:setLangValue(301014);
		self.condition_1.text = nil;
		self.condition_2.text = nil;
		self.des.text = nil;
	else
		DataCenter.roleData.selectDressUpId = data.id;
		self.btnFunc:setBtnEnable(true);
		self:superCall("onDressUpSelected", data);
		self.avatarItem:setRoleTitle(data.id);
		self.clockIcon:setEnable(true);
		self.prompt.text = nil;
	end

	self.itemList:updateShowList()
end

function Lua_DressUpTitlePanel:onBtnAdditionClick(go)
	local arr = DataCenter.roleUtil:getDressUpArr(self.mainType);
	local dic = {};
	for i = 1, arr:getSize() do
		if arr[i].is_active == 1 then
			DataCenter.attributesUtil:getAttrDic(arr[i].prop, dic);
		end
	end
	
	arr = DataCenter.attributesUtil:getAttrArrByDic(dic);
	if arr:getSize() <= 0 then
		OperateAlert.showLangValue(301015);
	else
		Lua_WindowUtil.openWin("Lua_DressUpAdditionWindow", Lua_WinParam.ACTION_OPEN, arr);
	end
end




















Lua_DressUpTitleItem = class("Lua_DressUpTitleItem", Lua_ListCell);
function Lua_DressUpTitleItem:ctor(p)
	self:superCall("ctor", p, "DressUpTitleItem_skin");
end

function Lua_DressUpTitleItem:buildShowItem()
	self:superCall("buildShowItem");
	self.selectIcon:setEnable(false);
end

function Lua_DressUpTitleItem:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_DressUpTitleItem:setData(data)
	self.data = data;
	self:updateData()
end

function Lua_DressUpTitleItem:updateData()
	self.titleIcon:setAltas(self.data.atlas, self.data.sprite);
	self.titleIcon:resetSize();
	self.titleIcon:setGray(self.data.is_active ~= 1);
	
	if self.data.is_wear == 1 then
		self.signIcon:setEnable(true);
		self.signIcon:setAltas("role_atlas", "ui_grxx_label_02");
	elseif self.data.canActivate == 1 then
		self.signIcon:setEnable(true);
		self.signIcon:setAltas("role_atlas", "ui_grxx_label_01");
	else
		self.signIcon:setEnable(false);
	end
	self.signIcon:resetSize();
	self.attr.text = self.data.attrStr;

	self:checkSelected()
end

function Lua_DressUpTitleItem:checkSelected()
	if self.data.id == DataCenter.roleData.selectDressUpId then
		self.selectIcon:setEnable(true);
	else
		self.selectIcon:setEnable(false);
	end
end

function Lua_DressUpTitleItem:onPressClick()
	if self.data == nil then
		return false;
	end
	Lua_MsgUtil.callFunc("SELECT_DRESSUP", self.data);
	return true;
end