Lua_SetUpWindow = class("Lua_SetUpWindow", Lua_Window);
function Lua_SetUpWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_SetUpWindow";
	self.skinName = "SetUpWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_SetUpWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.sliderMusic = Lua_SliderProgressBar.new(self.content, "role_atlas", "ui_grxx_progress_001_b", "ui_grxx_progress_001_f", "ui_grxx_progress_001_t", 466, 34);
	self.sliderMusic:setLocation(35, 203, 0);
	self.sliderMusic:setValue(PlayerPrefsUtil.instance.musicVolume, 0, 100);
	self.sliderMusic:setCallBack(self, self.updateMusicVolume, self.updateMusicVolumeEnd);

	self.sliderSound = Lua_SliderProgressBar.new(self.content, "role_atlas", "ui_grxx_progress_001_b", "ui_grxx_progress_001_f", "ui_grxx_progress_001_t", 466, 34);
	self.sliderSound:setLocation(35, 148.5, 0);
	self.sliderSound:setValue(PlayerPrefsUtil.instance.soundVolume, 0, 100);
	self.sliderSound:setCallBack(self, self.updateSoundVolume, self.updateSoundVolumeEnd);
	--高品质
	self.cbHighQuality.selected = PlayerPrefsUtil.instance.qualityLevel >= 2;
	self.cbHighQuality:addBoxChange(self, self.onHighQualityChange);
	--流畅
	self.cbSmooth.selected = PlayerPrefsUtil.instance.qualityLevel == 1;
	self.cbSmooth:addBoxChange(self, self.onSmoothChange);
	--省电
	self.cbPowerSaving.selected = PlayerPrefsUtil.instance.qualityLevel == 0;
	self.cbPowerSaving:addBoxChange(self, self.onPowerSavingChange);

	self.btnExit:addClickFuntion(self, self.onBtnExitClick);
	self.btnSwitch:addClickFuntion(self, self.onBtnSwitchClick);

	self:updateShowInfo();
end

function Lua_SetUpWindow:dispose()
	if self.sliderMusic ~= nil then
		self.sliderMusic:dispose();
		self.sliderMusic = nil;
	end
	if self.sliderSound ~= nil then
		self.sliderSound:dispose();
		self.sliderSound = nil;
	end
	self:superCall("dispose");
end

function Lua_SetUpWindow:updateShowInfo()
	local server_name = string.split(DataCenter.roleData.server_name, "#");
	self.serverName.text = LanUtil.formateStr(300017, server_name[2]);
	self.serverName:resetSize();
	self.serverBg:SetDimensions(self.serverName.width + 30, 48);
end

function Lua_SetUpWindow:updateMusicVolume(count)
	PlayerPrefsUtil.instance.musicVolume = count;
end

function Lua_SetUpWindow:updateMusicVolumeEnd(count)
	self:sendSetUp();
end

function Lua_SetUpWindow:updateSoundVolume(count)
	PlayerPrefsUtil.instance.soundVolume = count;
end

function Lua_SetUpWindow:updateSoundVolumeEnd(count)
	self:sendSetUp();
end

function Lua_SetUpWindow:onHighQualityChange(bChange)
	if bChange then
		self.cbSmooth.selected = false;
		self.cbPowerSaving.selected = false;
		PlayerPrefsUtil.instance.qualityLevel = 2;
		self:sendSetUp();
	else
		OperateAlert.showLangValue(300018);
		self.cbHighQuality.selected = true;
	end
end

function Lua_SetUpWindow:onSmoothChange(bChange)
	if bChange then
		self.cbHighQuality.selected = false;
		self.cbPowerSaving.selected = false;
		PlayerPrefsUtil.instance.qualityLevel = 1;
		self:sendSetUp();
	else
		OperateAlert.showLangValue(300018);
		self.cbSmooth.selected = true;
	end
end

function Lua_SetUpWindow:onPowerSavingChange(bChange)
	if bChange then
		self.cbHighQuality.selected = false;
		self.cbSmooth.selected = false;
		PlayerPrefsUtil.instance.qualityLevel = 0;
		self:sendSetUp();
	else
		OperateAlert.showLangValue(300018);
		self.cbPowerSaving.selected = true;
	end
end

function Lua_SetUpWindow:sendSetUp()
	local tab = {};
	tab[SetUpDefine.quality_level] = PlayerPrefsUtil.instance.qualityLevel;
	tab[SetUpDefine.music_volume] = PlayerPrefsUtil.instance.musicVolume;
	tab[SetUpDefine.sound_volume] = PlayerPrefsUtil.instance.soundVolume;
	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sSetUp(tab);
end

function Lua_SetUpWindow:onBtnExitClick(go)
	if Lua_PlatformUtil.IsAndroid() == true or Lua_PlatformUtil.IsIPhonePlayer() == true then
		DataCenter.sdkInterface:callSDKInterface(Lua_SDKMessageType.Exit);
	else
		local tipsData = { posY = 30, des = LanUtil.getValue(300019), btnType = 1, owner = self, sureFun = self.onReLogin };
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	end
end

function Lua_SetUpWindow:onBtnSwitchClick(go)
	if Lua_PlatformUtil.IsAndroid() == true or Lua_PlatformUtil.IsIPhonePlayer() == true then
		self:onReLogin();
	else
		local tipsData = { posY = 30, des = LanUtil.getValue(300020), btnType = 1, owner = self, sureFun = self.onReLogin };
		Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	end
end

function Lua_SetUpWindow:onReLogin()
	LoadManager.getInstance():Load(Lua_LoadFileType.IMG, "/images/loading/login_bg.jpg", nil, nil, nil, nil, 999, 30);
	DataCenter.connectionManager:relogin();
end